/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.soa.esb.samples.quickstart.loanfault.test;

import org.jboss.soa.esb.message.Message;
import org.jboss.soa.esb.message.format.MessageFactory;
import org.jboss.soa.esb.client.ServiceInvoker;

/**
 * Standalone class with to send ESB messages to a 'known' [category,name].
 * <p/> arg0 - service category
 * <br/>arg1 - service name
 * <br/>arg2 - Text of message to send
 * 
 * @author <a href="mailto:schifest@heuristica.com.ar">schifest@heuristica.com.ar</a>
 * @since Version 4.0
 *
 */
public class SendEsbMessage 
{
    protected static final String ESB_FAULT_CODE = "org.jboss.soa.esb.message.fault.detail.code";
    protected static final String BPEL_FAULT_CODE = "org.jboss.soa.bpel.message.fault.detail.code";
    protected static final String FAULT_MESSAGE = "org.jboss.soa.esb.message.fault.detail.detail";

    public static void main(String args[]) throws Exception
    {
    	// Setting the ConnectionFactory such that it will use scout
        System.setProperty("javax.xml.registry.ConnectionFactoryClass","org.apache.ws.scout.registry.ConnectionFactoryImpl");
        
    	if (args.length < 3)
    	{
    		System.err.println("Usage SendEsbMessage <category> <name> <text to send>");
    		System.exit(1);
    	}
    	
    	Message esbMessage = MessageFactory.getInstance().getMessage();

    	esbMessage.getBody().add(args[2]);
    	
    	try {
    		Message respMessage = new ServiceInvoker(args[0], args[1]).deliverSync(esbMessage, 5000);
    	
    		System.out.println("REPLY: "+respMessage.getBody().get());
    	} catch(org.jboss.soa.esb.couriers.FaultMessageException fme) {
    		System.out.println("FAULT TYPE (AS QNAME): "+fme.getReturnedMessage().getBody().get(ESB_FAULT_CODE));
    		System.out.println("FAULT TYPE (AS STRING): "+fme.getReturnedMessage().getBody().get(BPEL_FAULT_CODE));
			System.out.println("FAULT MESSAGE: "+fme.getReturnedMessage().getBody().get(FAULT_MESSAGE));
    	}
    }
    
}
